@@ -1,5 +1,5 @@
 from .webapi import MetaCatClient
 from .webapi import ServerError as MCServerError
-from .webapi import AuthenticationError as MCAuthenticationError
+from .webapi import AuthenticationError
 from .webapi import WebAPIError as MCWebAPIError
 from .webapi import InvalidMetadataError as MCInvalidMetadataError
\ No newline at end of file
